
#ifndef _GDFONTMB_H_
#define _GDFONTMB_H_ 1

/*
	This is a header file for gd font, generated using
	bdftogd version 0.60 by Jan Pazdziora, adelton@fi.muni.cz
	from bdf font
	-Gemini-Fixed-Bold-R-Normal--16-120-100-100-C-80-KOI8-U
	at Tue Jan 29 07:24:09 2002.
	The original bdf was holding following copyright:
	"Copyright (C) 1994 Aleksei Rudnev <alex@kiae.su>"
 */


#include "gd.h"

extern gdFontPtr gdFontMediumBold;

#endif

